==> gatsby-plugin-graphql-config-0.9.0.tgz: package/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

# [0.9.0](https://github.com/gatsbyjs/gatsby/compare/gatsby-plugin-graphql-config@0.9.0-v3rc.0...gatsby-plugin-graphql-config@0.9.0) (2021-03-02)

**Note:** Version bump only for package gatsby-plugin-graphql-config

# [0.9.0-v3rc.0](https://github.com/gatsbyjs/gatsby/compare/gatsby-plugin-graphql-config@0.9.0-next.0...gatsby-plugin-graphql-config@0.9.0-v3rc.0) (2021-02-26)

**Note:** Version bump only for package gatsby-plugin-graphql-config

# [0.9.0-next.0](https://github.com/gatsbyjs/gatsby/compare/gatsby-plugin-graphql-config@0.8.0-next.0...gatsby-plugin-graphql-config@0.9.0-next.0) (2021-02-05)

**Note:** Version bump only for package gatsby-plugin-graphql-config

# [0.8.0-next.0](https://github.com/gatsbyjs/gatsby/compare/gatsby-plugin-graphql-config@0.7.0-next.0...gatsby-plugin-graphql-config@0.8.0-next.0) (2021-01-28)

### Bug Fixes

- **deps:** update minor and patch for gatsby-plugin-graphql-config ([#29178](https://github.com/gatsbyjs/gatsby/issues/29178)) ([fcb65e2](https://github.com/gatsbyjs/gatsby/commit/fcb65e2e52135b0866277df35dec40f35f7873d1))

# [0.7.0-next.0](https://github.com/gatsbyjs/gatsby/compare/gatsby-plugin-graphql-config@0.6.0-next.0...gatsby-plugin-graphql-config@0.7.0-next.0) (2021-01-18)

**Note:** Version bump only for package gatsby-plugin-graphql-config

# [0.6.0-next.0](https://github.com/gatsbyjs/gatsby/compare/gatsby-plugin-graphql-config@0.5.0-next.0...gatsby-plugin-graphql-config@0.6.0-next.0) (2020-12-29)

**Note:** Version bump only for package gatsby-plugin-graphql-config

# [0.5.0-next.0](https://github.com/gatsbyjs/gatsby/compare/gatsby-plugin-graphql-config@0.4.0-next.0...gatsby-plugin-graphql-config@0.5.0-next.0) (2020-12-10)

**Note:** Version bump only for package gatsby-plugin-graphql-config

# [0.4.0-next.0](https://github.com/gatsbyjs/gatsby/compare/gatsby-plugin-graphql-config@0.3.0-next.0...gatsby-plugin-graphql-config@0.4.0-next.0) (2020-11-26)

**Note:** Version bump only for package gatsby-plugin-graphql-config

# [0.3.0-next.0](https://github.com/gatsbyjs/gatsby/compare/gatsby-plugin-graphql-config@0.2.0-next.0...gatsby-plugin-graphql-config@0.3.0-next.0) (2020-11-18)

**Note:** Version bump only for package gatsby-plugin-graphql-config

# [0.1.0-next.1](https://github.com/gatsbyjs/gatsby/compare/gatsby-plugin-graphql-config@0.1.0-next.0...gatsby-plugin-graphql-config@0.1.0-next.1) (2020-11-10)

**Note:** Version bump only for package gatsby-plugin-graphql-config

## [0.0.3](https://github.com/gatsbyjs/gatsby/compare/gatsby-plugin-graphql-config@0.0.2...gatsby-plugin-graphql-config@0.0.3) (2020-09-28)

**Note:** Version bump only for package gatsby-plugin-graphql-config

## [0.0.2](https://github.com/gatsbyjs/gatsby/compare/gatsby-plugin-graphql-config@0.0.1...gatsby-plugin-graphql-config@0.0.2) (2020-09-24)

**Note:** Version bump only for package gatsby-plugin-graphql-config

## 0.0.1 (2020-09-23)

### Bug Fixes

- **gatsby-plugin-graphql-config:** add dependencies ([#26970](https://github.com/gatsbyjs/gatsby/issues/26970)) ([5c5c045](https://github.com/gatsbyjs/gatsby/commit/5c5c045ea1da84d7a788a69963752fce2cfe08d8))

==> gatsby-plugin-graphql-config-0.10.0.tgz: package/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

# [0.10.0](https://github.com/gatsbyjs/gatsby/compare/gatsby-plugin-graphql-config@0.10.0-next.1...gatsby-plugin-graphql-config@0.10.0) (2021-03-16)

**Note:** Version bump only for package gatsby-plugin-graphql-config

# [0.10.0-next.1](https://github.com/gatsbyjs/gatsby/compare/gatsby-plugin-graphql-config@0.10.0-next.0...gatsby-plugin-graphql-config@0.10.0-next.1) (2021-02-26)

**Note:** Version bump only for package gatsby-plugin-graphql-config

# [0.10.0-next.0](https://github.com/gatsbyjs/gatsby/compare/gatsby-plugin-graphql-config@0.9.0-next.0...gatsby-plugin-graphql-config@0.10.0-next.0) (2021-02-26)

**Note:** Version bump only for package gatsby-plugin-graphql-config

# [0.9.0-next.0](https://github.com/gatsbyjs/gatsby/compare/gatsby-plugin-graphql-config@0.8.0-next.0...gatsby-plugin-graphql-config@0.9.0-next.0) (2021-02-05)

**Note:** Version bump only for package gatsby-plugin-graphql-config

# [0.8.0-next.0](https://github.com/gatsbyjs/gatsby/compare/gatsby-plugin-graphql-config@0.7.0-next.0...gatsby-plugin-graphql-config@0.8.0-next.0) (2021-01-28)

### Bug Fixes

- **deps:** update minor and patch for gatsby-plugin-graphql-config ([#29178](https://github.com/gatsbyjs/gatsby/issues/29178)) ([fcb65e2](https://github.com/gatsbyjs/gatsby/commit/fcb65e2e52135b0866277df35dec40f35f7873d1))

# [0.7.0-next.0](https://github.com/gatsbyjs/gatsby/compare/gatsby-plugin-graphql-config@0.6.0-next.0...gatsby-plugin-graphql-config@0.7.0-next.0) (2021-01-18)

**Note:** Version bump only for package gatsby-plugin-graphql-config

# [0.6.0-next.0](https://github.com/gatsbyjs/gatsby/compare/gatsby-plugin-graphql-config@0.5.0-next.0...gatsby-plugin-graphql-config@0.6.0-next.0) (2020-12-29)

**Note:** Version bump only for package gatsby-plugin-graphql-config

# [0.5.0-next.0](https://github.com/gatsbyjs/gatsby/compare/gatsby-plugin-graphql-config@0.4.0-next.0...gatsby-plugin-graphql-config@0.5.0-next.0) (2020-12-10)

**Note:** Version bump only for package gatsby-plugin-graphql-config

# [0.4.0-next.0](https://github.com/gatsbyjs/gatsby/compare/gatsby-plugin-graphql-config@0.3.0-next.0...gatsby-plugin-graphql-config@0.4.0-next.0) (2020-11-26)

**Note:** Version bump only for package gatsby-plugin-graphql-config

# [0.3.0-next.0](https://github.com/gatsbyjs/gatsby/compare/gatsby-plugin-graphql-config@0.2.0-next.0...gatsby-plugin-graphql-config@0.3.0-next.0) (2020-11-18)

**Note:** Version bump only for package gatsby-plugin-graphql-config

# [0.1.0-next.1](https://github.com/gatsbyjs/gatsby/compare/gatsby-plugin-graphql-config@0.1.0-next.0...gatsby-plugin-graphql-config@0.1.0-next.1) (2020-11-10)

**Note:** Version bump only for package gatsby-plugin-graphql-config

## [0.0.3](https://github.com/gatsbyjs/gatsby/compare/gatsby-plugin-graphql-config@0.0.2...gatsby-plugin-graphql-config@0.0.3) (2020-09-28)

**Note:** Version bump only for package gatsby-plugin-graphql-config

## [0.0.2](https://github.com/gatsbyjs/gatsby/compare/gatsby-plugin-graphql-config@0.0.1...gatsby-plugin-graphql-config@0.0.2) (2020-09-24)

**Note:** Version bump only for package gatsby-plugin-graphql-config

## 0.0.1 (2020-09-23)

### Bug Fixes

- **gatsby-plugin-graphql-config:** add dependencies ([#26970](https://github.com/gatsbyjs/gatsby/issues/26970)) ([5c5c045](https://github.com/gatsbyjs/gatsby/commit/5c5c045ea1da84d7a788a69963752fce2cfe08d8))
